@@ -85,6 +85,7 @@ RZ_API RzBinLanguage rz_bin_language_detect(RzBinFile *binfile) {
 	RzBinObject *o = binfile->o;
 	RzBinInfo *info = o->info;
 	RzBinSymbol *sym;
+	RzBinImport *imp;
 	RzBinSection *section;
 	RzListIter *iter;
 
@@ -100,6 +101,8 @@ RZ_API RzBinLanguage rz_bin_language_detect(RzBinFile *binfile) {
 	}
 
 	bool is_macho = info->rclass ? strstr(info->rclass, "mach") : false;
+	bool is_dyldc = info->bclass ? strstr(info->bclass, "dyldcache") : false;
+	bool is_xnu_kernelcache = info->bclass ? strstr(info->bclass, "kernelcache") : false;
 	bool is_elf = info->rclass ? strstr(info->rclass, "elf") : false;
 	bool is_pe = info->rclass ? strstr(info->rclass, "pe") : false;
 	bool is_class = info->rclass ? strstr(info->rclass, "class") : false;
@@ -108,13 +111,13 @@ RZ_API RzBinLanguage rz_bin_language_detect(RzBinFile *binfile) {
 	bool is_cpp = false;
 	char *lib = NULL;
 
-	if (!is_macho && !is_elf && !is_pe && !is_class) {
+	if (!is_macho && !is_dyldc && !is_xnu_kernelcache && !is_elf && !is_pe && !is_class) {
 		return RZ_BIN_LANGUAGE_UNKNOWN;
 	}
 
 	if (is_macho || is_elf) {
-		rz_list_foreach (o->imports, iter, sym) {
-			const char *name = sym->name;
+		rz_list_foreach (o->imports, iter, imp) {
+			const char *name = imp->name;
 			if (!strcmp(name, "_NSConcreteGlobalBlock")) {
 				is_blocks = true;
 			} else if (!strncmp(name, "objc_", 5)) {
