@@ -424,7 +424,28 @@ static pyc_object *get_string_object(RzBuffer *buffer) {
 	return ret;
 }
 
-static pyc_object *get_unicode_object(RzBuffer *buffer) {
+static bool add_string_to_cache(RzBinPycObj *pyc, ut64 addr, const char *data, ut32 size, ut32 length, RzStrEnc type) {
+	if (size == 0) {
+		return true;
+	}
+
+	RzBinString *string = RZ_NEW0(RzBinString);
+	if (!string) {
+		return false;
+	}
+	string->paddr = string->vaddr = addr;
+	string->size = size;
+	string->length = length;
+	string->ordinal = 0;
+	string->type = type;
+	string->string = rz_str_new(data);
+	if (!rz_list_append(pyc->strings_cache, string)) {
+		return false;
+	}
+	return true;
+}
+
+static pyc_object *get_unicode_object(RzBinPycObj *pyc, RzBuffer *buffer) {
 	pyc_object *ret = NULL;
 	bool error = false;
 	ut32 n = 0;
@@ -437,6 +458,7 @@ static pyc_object *get_unicode_object(RzBuffer *buffer) {
 	if (error) {
 		return NULL;
 	}
+	ut64 addr = rz_buf_tell(buffer);
 	ret = RZ_NEW0(pyc_object);
 	ret->type = TYPE_UNICODE;
 	ret->data = get_bytes(buffer, n);
@@ -444,6 +466,11 @@ static pyc_object *get_unicode_object(RzBuffer *buffer) {
 		RZ_FREE(ret);
 		return NULL;
 	}
+
+	if (!add_string_to_cache(pyc, addr, ret->data, n, rz_utf8_strlen(ret->data), RZ_STRING_ENC_UTF8)) {
+		RZ_FREE(ret);
+		return NULL;
+	}
 	return ret;
 }
 
@@ -627,22 +654,29 @@ static pyc_object *get_set_object(RzBinPycObj *pyc, RzBuffer *buffer) {
 	return ret;
 }
 
-static pyc_object *get_ascii_object_generic(RzBuffer *buffer, ut32 size, bool interned) {
+static pyc_object *get_ascii_object_generic(RzBinPycObj *pyc, RzBuffer *buffer, ut32 size, bool interned) {
 	pyc_object *ret = NULL;
 
 	ret = RZ_NEW0(pyc_object);
 	if (!ret) {
 		return NULL;
 	}
+
+	ut64 addr = rz_buf_tell(buffer);
 	ret->type = TYPE_ASCII;
 	ret->data = get_bytes(buffer, size);
 	if (!ret->data) {
 		RZ_FREE(ret);
 	}
+
+	if (!add_string_to_cache(pyc, addr, ret->data, size, size, RZ_STRING_ENC_8BIT)) {
+		RZ_FREE(ret);
+		return NULL;
+	}
 	return ret;
 }
 
-static pyc_object *get_ascii_object(RzBuffer *buffer) {
+static pyc_object *get_ascii_object(RzBinPycObj *pyc, RzBuffer *buffer) {
 	bool error = false;
 	ut32 n = 0;
 
@@ -650,10 +684,10 @@ static pyc_object *get_ascii_object(RzBuffer *buffer) {
 	if (error) {
 		return NULL;
 	}
-	return get_ascii_object_generic(buffer, n, true);
+	return get_ascii_object_generic(pyc, buffer, n, true);
 }
 
-static pyc_object *get_ascii_interned_object(RzBuffer *buffer) {
+static pyc_object *get_ascii_interned_object(RzBinPycObj *pyc, RzBuffer *buffer) {
 	bool error = false;
 	ut32 n;
 
@@ -661,10 +695,10 @@ static pyc_object *get_ascii_interned_object(RzBuffer *buffer) {
 	if (error) {
 		return NULL;
 	}
-	return get_ascii_object_generic(buffer, n, true);
+	return get_ascii_object_generic(pyc, buffer, n, true);
 }
 
-static pyc_object *get_short_ascii_object(RzBuffer *buffer) {
+static pyc_object *get_short_ascii_object(RzBinPycObj *pyc, RzBuffer *buffer) {
 	bool error = false;
 	ut8 n;
 
@@ -672,10 +706,10 @@ static pyc_object *get_short_ascii_object(RzBuffer *buffer) {
 	if (error) {
 		return NULL;
 	}
-	return get_ascii_object_generic(buffer, n, false);
+	return get_ascii_object_generic(pyc, buffer, n, false);
 }
 
-static pyc_object *get_short_ascii_interned_object(RzBuffer *buffer) {
+static pyc_object *get_short_ascii_interned_object(RzBinPycObj *pyc, RzBuffer *buffer) {
 	bool error = false;
 	ut8 n;
 
@@ -683,7 +717,7 @@ static pyc_object *get_short_ascii_interned_object(RzBuffer *buffer) {
 	if (error) {
 		return NULL;
 	}
-	return get_ascii_object_generic(buffer, n, true);
+	return get_ascii_object_generic(pyc, buffer, n, true);
 }
 
 static pyc_object *get_ref_object(RzBinPycObj *pyc, RzBuffer *buffer) {
@@ -866,7 +900,7 @@ static pyc_object *get_code_object(RzBinPycObj *pyc, RzBuffer *buffer) {
 	bool v15_to_22 = magic_int_within(pyc->magic_int, 20121, 60718, &error); // 1.5a1 - 2.2a1
 	bool v13_to_20 = magic_int_within(pyc->magic_int, 11913, 50824, &error); // 1.3b1 - 2.0b1
 	// bool v21_to_27 = (!v13_to_20) && magic_int_within (magic_int, 60124, 62212, &error);
-	bool has_posonlyargcount = magic_int_within(pyc->magic_int, 3410, 3424, &error); // v3.8.0a4 - latest
+	bool has_posonlyargcount = magic_int_within(pyc->magic_int, 3410, 3491, &error); // v3.8.0a4 - latest
 	if (error) {
 		free(ret);
 		free(cobj);
@@ -1051,16 +1085,16 @@ static pyc_object *get_object(RzBinPycObj *pyc, RzBuffer *buffer) {
 		ret = get_int_object(buffer);
 		break;
 	case TYPE_ASCII_INTERNED:
-		ret = get_ascii_interned_object(buffer);
+		ret = get_ascii_interned_object(pyc, buffer);
 		break;
 	case TYPE_SHORT_ASCII:
-		ret = get_short_ascii_object(buffer);
+		ret = get_short_ascii_object(pyc, buffer);
 		break;
 	case TYPE_ASCII:
-		ret = get_ascii_object(buffer);
+		ret = get_ascii_object(pyc, buffer);
 		break;
 	case TYPE_SHORT_ASCII_INTERNED:
-		ret = get_short_ascii_interned_object(buffer);
+		ret = get_short_ascii_interned_object(pyc, buffer);
 		break;
 	case TYPE_INT64:
 		ret = get_int64_object(buffer);
@@ -1090,7 +1124,7 @@ static pyc_object *get_object(RzBinPycObj *pyc, RzBuffer *buffer) {
 		ret = get_long_object(buffer);
 		break;
 	case TYPE_UNICODE:
-		ret = get_unicode_object(buffer);
+		ret = get_unicode_object(pyc, buffer);
 		break;
 	case TYPE_DICT:
 		ret = get_dict_object(pyc, buffer);
@@ -1151,6 +1185,7 @@ static bool extract_sections_symbols(RzBinPycObj *pyc, pyc_object *obj, RzList /
 	if (!section->name) {
 		goto fail;
 	}
+	section->has_strings = false;
 	section->paddr = cobj->start_offset;
 	section->vaddr = cobj->start_offset;
 	section->size = cobj->end_offset - cobj->start_offset;
