@@ -69,7 +69,7 @@ static bool windbg_init(RzDebug *dbg, void **user) {
 	return idbg->initialized;
 }
 
-static int windbg_step(RzDebug *dbg) {
+static bool windbg_step(RzDebug *dbg) {
 	DbgEngContext *idbg = dbg->plugin_data;
 	rz_return_val_if_fail(idbg && idbg->initialized, 0);
 	idbg->lastExecutionStatus = DEBUG_STATUS_STEP_INTO;
@@ -209,7 +209,7 @@ static int windbg_wait(RzDebug *dbg, int pid) {
 	return ret;
 }
 
-static int windbg_step_over(RzDebug *dbg) {
+static bool windbg_step_over(RzDebug *dbg) {
 	DbgEngContext *idbg = dbg->plugin_data;
 	rz_return_val_if_fail(idbg && idbg->initialized, 0);
 	idbg->lastExecutionStatus = DEBUG_STATUS_STEP_OVER;
