@@ -60,6 +60,40 @@ bool rz_il_handler_store(RzILVM *vm, RzILOpEffect *op);
 void *rz_il_handler_loadw(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
 bool rz_il_handler_storew(RzILVM *vm, RzILOpEffect *op);
 
+void *rz_il_handler_float(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fbits(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_is_finite(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_is_nan(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_is_inf(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_is_fzero(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_is_fneg(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_is_fpos(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fneg(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fabs(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fcast_int(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fcast_sint(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fcast_float(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fcast_sfloat(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fconvert(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_frequal(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fsucc(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fpred(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_forder(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fround(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fsqrt(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_frsqrt(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fadd(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fsub(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fdiv(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fmul(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fmod(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fhypot(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fpow(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fmad(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_frootn(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fpown(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+void *rz_il_handler_fcompound(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
+
 // TODO: remove me when all the handlers are implemented
 void *rz_il_handler_pure_unimplemented(RzILVM *vm, RzILOpPure *op, RzILTypePure *type);
 bool rz_il_handler_effect_unimplemented(RzILVM *vm, RzILOpEffect *op);
@@ -99,6 +133,45 @@ RZ_IPI RzILOpPureHandler rz_il_op_handler_pure_table_default[RZ_IL_OP_PURE_MAX]
 	[RZ_IL_OP_APPEND] = rz_il_handler_append,
 	[RZ_IL_OP_LOAD] = rz_il_handler_load,
 	[RZ_IL_OP_LOADW] = rz_il_handler_loadw,
+
+	// Fbasic Theory
+	[RZ_IL_OP_FLOAT] = rz_il_handler_float,
+	[RZ_IL_OP_FBITS] = rz_il_handler_fbits,
+	[RZ_IL_OP_IS_FINITE] = rz_il_handler_is_finite,
+	[RZ_IL_OP_IS_NAN] = rz_il_handler_is_nan,
+	[RZ_IL_OP_IS_INF] = rz_il_handler_is_inf,
+	[RZ_IL_OP_IS_FZERO] = rz_il_handler_is_fzero,
+	[RZ_IL_OP_IS_FNEG] = rz_il_handler_is_fneg,
+	[RZ_IL_OP_IS_FPOS] = rz_il_handler_is_fpos,
+	[RZ_IL_OP_FNEG] = rz_il_handler_fneg,
+	[RZ_IL_OP_FABS] = rz_il_handler_fabs,
+	[RZ_IL_OP_FREQUAL] = rz_il_handler_frequal,
+	[RZ_IL_OP_FSUCC] = rz_il_handler_fsucc,
+	[RZ_IL_OP_FPRED] = rz_il_handler_fpred,
+	[RZ_IL_OP_FORDER] = rz_il_handler_forder,
+	[RZ_IL_OP_FROUND] = rz_il_handler_fround,
+	[RZ_IL_OP_FSQRT] = rz_il_handler_fsqrt,
+	[RZ_IL_OP_FRSQRT] = rz_il_handler_pure_unimplemented,
+	[RZ_IL_OP_FADD] = rz_il_handler_fadd,
+	[RZ_IL_OP_FSUB] = rz_il_handler_fsub,
+	[RZ_IL_OP_FMUL] = rz_il_handler_fmul,
+	[RZ_IL_OP_FDIV] = rz_il_handler_fdiv,
+	[RZ_IL_OP_FMOD] = rz_il_handler_fmod,
+	[RZ_IL_OP_FMAD] = rz_il_handler_fmad,
+
+	[RZ_IL_OP_FCAST_INT] = rz_il_handler_fcast_int,
+	[RZ_IL_OP_FCAST_SINT] = rz_il_handler_fcast_sint,
+	[RZ_IL_OP_FCAST_FLOAT] = rz_il_handler_fcast_float,
+	[RZ_IL_OP_FCAST_SFLOAT] = rz_il_handler_fcast_sfloat,
+	[RZ_IL_OP_FCONVERT] = rz_il_handler_fconvert,
+
+	// Float Theory
+	// TODO : Implement other Float Theory operations
+	[RZ_IL_OP_FHYPOT] = rz_il_handler_pure_unimplemented,
+	[RZ_IL_OP_FPOW] = rz_il_handler_pure_unimplemented,
+	[RZ_IL_OP_FROOTN] = rz_il_handler_pure_unimplemented,
+	[RZ_IL_OP_FPOWN] = rz_il_handler_pure_unimplemented,
+	[RZ_IL_OP_FCOMPOUND] = rz_il_handler_pure_unimplemented,
 };
 
 RZ_IPI RzILOpEffectHandler rz_il_op_handler_effect_table_default[RZ_IL_OP_EFFECT_MAX] = {
@@ -245,9 +318,9 @@ static void *eval_pure(RZ_NONNULL RzILVM *vm, RZ_NONNULL RzILOpPure *op, RZ_NONN
 }
 
 static bool eval_effect(RZ_NONNULL RzILVM *vm, RZ_NONNULL RzILOpEffect *op) {
-	rz_return_val_if_fail(vm && op, NULL);
+	rz_return_val_if_fail(vm && op, false);
 	RzILOpEffectHandler handler = vm->op_handler_effect_table[op->code];
-	rz_return_val_if_fail(handler, NULL);
+	rz_return_val_if_fail(handler, false);
 	return handler(vm, op);
 }
 
@@ -257,6 +330,8 @@ static const char *pure_type_name(RzILTypePure type) {
 		return "bitvector";
 	case RZ_IL_TYPE_PURE_BOOL:
 		return "bool";
+	case RZ_IL_TYPE_PURE_FLOAT:
+		return "float";
 	default:
 		return "unknown";
 	}
@@ -320,6 +395,8 @@ RZ_API RZ_NULLABLE RZ_OWN RzILVal *rz_il_evaluate_val(RZ_NONNULL RzILVM *vm, RZ_
 		return rz_il_value_new_bool(res);
 	case RZ_IL_TYPE_PURE_BITVECTOR:
 		return rz_il_value_new_bitv(res);
+	case RZ_IL_TYPE_PURE_FLOAT:
+		return rz_il_value_new_float(res);
 	default:
 		RZ_LOG_ERROR("RzIL: type error: got %s\n", pure_type_name(type));
 		return NULL;
@@ -342,3 +419,24 @@ RZ_API bool rz_il_evaluate_effect(RZ_NONNULL RzILVM *vm, RZ_NONNULL RzILOpEffect
 	rz_return_val_if_fail(vm && op, false);
 	return eval_effect(vm, op);
 }
+
+/**
+ * Evaluate the given pure op, return the float
+ * \return NULL if an error occured
+ */
+RZ_API RZ_NULLABLE RZ_OWN RzFloat *rz_il_evaluate_float(RZ_NONNULL RzILVM *vm, RZ_NONNULL RzILOpPure *op) {
+	rz_return_val_if_fail(vm && op, NULL);
+
+	// check type and auto convertion between bitv/bool/val
+	RzILTypePure type = -1;
+	void *res = eval_pure(vm, op, &type);
+	if (!res) {
+		// propagate error
+		return NULL;
+	}
+	if (type != RZ_IL_TYPE_PURE_FLOAT) {
+		RZ_LOG_ERROR("RzIL: type error: expected float, got %s\n", pure_type_name(type));
+		return NULL;
+	}
+	return res;
+}
