@@ -251,6 +251,9 @@ static int rzfind_open_file(RzfindOptions *ro, const char *file, const ut8 *data
 		if (ro->import) {
 			imports = rz_bin_object_get_imports(bf->o);
 			rz_list_foreach (ro->keywords, iter, kw) {
+				if (!kw) {
+					continue;
+				}
 				rz_list_foreach (imports, it, import) {
 					if (!strcmp(import->name, kw)) {
 						printf("ordinal: %d %s\n", import->ordinal, kw);
@@ -262,6 +265,9 @@ static int rzfind_open_file(RzfindOptions *ro, const char *file, const ut8 *data
 		if (ro->symbol) {
 			symbols = rz_bin_object_get_symbols(bf->o);
 			rz_list_foreach (ro->keywords, iter, kw) {
+				if (!kw) {
+					continue;
+				}
 				rz_list_foreach (symbols, it, symbol) {
 					if (!symbol->name) {
 						continue;
